@@ -10,7 +10,9 @@ def metropolis_acceptance(cost, new_cost, temperature):
 		return p
 
 """
+
 Various Copy Strategies
+
 """
 
 def copy(state):
@@ -22,9 +24,15 @@ def deepcopy(state):
 def naked(state):
 	return state
 
+
+"""
+
+Simulated Annealing Scheme
+
+"""
 def sa(	random_start,
-		cost_function,
-		random_neighbours,
+		objective_function,
+		random_movements,
 		acceptance = metropolis_acceptance,
 		T_start = 5,
 		T_stop = 0.05,
@@ -37,23 +45,23 @@ def sa(	random_start,
 	
 	Arguments:
 		random_start: function which returns a random start / state
-		cost_function: objective function to minimize
-		random_neighbours: list of neighbor functions
+		objective_function: objective function to minimize
+		random_movements: **list** of neighbor functions, for one use [func]
 		t_start: Starting temperature
 		T_stop: Stopping temperature
 		alpha: lower temperature by this factor, after repeats proposals
-		repeats: at each lowewing by alpha, do repeats proposals
+		repeats: at each lowering by alpha, do repeats proposals
 		copy = {'copy', 'deepcopy', 'naked'} - copy method
 	
 	Output:
 		T: Temperature (the lower, the less likely a proposal with increasing costs is accepted)
 		M: Proportion of accepted states in last *repeats* proposals (Movements - keep moving when its cold)
-		C_min: Minimum Cost found so far, in all previous states
-		C_current: Current Cost of last-accepted-state
+		C_min: Minimum Objective Value found so far, in all previous states
+		C_current: Current Objective Value of last-accepted-state
 	
 	"""
 	state = random_start()
-	cost = cost_function(state)
+	cost = objective_function(state)
 	states, costs = [state], [cost]
 	best_found = copy_state(state)
 	best_found_cost = cost
@@ -75,10 +83,10 @@ def sa(	random_start,
 		movements=0
 		for _ in range(repeats):
 			
-			random_neighbour = random.choice( random_neighbours )
+			random_neighbour = random.choice( random_movements )
 			#print(random_neighbour)
 			new_state = random_neighbour(state)
-			new_cost = cost_function(new_state)
+			new_cost = objective_function(new_state)
 	
 			if acceptance(cost, new_cost, T) > random.random():
 				if new_cost != cost:
@@ -92,4 +100,4 @@ def sa(	random_start,
 					
 	print("---")
 	print("Best Found Cost: {:08.8f}".format(best_found_cost))
-	return best_found, cost_function(best_found)
\ No newline at end of file
+	return best_found, objective_function(best_found)
\ No newline at end of file
